@@ -12,7 +12,7 @@ use File::Which ();
 # Globals
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK $IMPLEMENTED_BY};
 BEGIN {
-	$VERSION = '0.91';
+	$VERSION = '0.93';
 
 	# Inherit manually
 	require Exporter;
@@ -27,6 +27,8 @@ BEGIN {
 		my_pictures
 		my_videos
 		my_data
+		my_dist_config
+		my_dist_data
 		users_home
 		users_desktop
 		users_documents
@@ -56,21 +58,14 @@ if ( $IMPLEMENTED_BY ) {
 	# All versions of Windows
 	$IMPLEMENTED_BY = 'File::HomeDir::Windows';
 } elsif ( $^O eq 'darwin') {
-	TRY: {
-		if ( $Config::Config{ptrsize} == 8 ) {
-			# 64bit: try Mac::SystemDirectory by chansen
-			if ( eval { require Mac::SystemDirectory; 1 } ) {
-				$IMPLEMENTED_BY = 'File::HomeDir::Darwin::Cocoa';
-				last TRY;
-			}
-
-		} elsif (eval { require Mac::Files; 1 }) {
-			# 32bit and has Mac::Files: Carbon
-			$IMPLEMENTED_BY = 'File::HomeDir::Darwin::Carbon';
-			last TRY;
-		}
-
-		# fallback: pure perl
+	# 1st: try Mac::SystemDirectory by chansen
+	if ( eval { require Mac::SystemDirectory; 1 } ) {
+		$IMPLEMENTED_BY = 'File::HomeDir::Darwin::Cocoa';
+	} elsif ( eval { require Mac::Files; 1 } ) {
+		# 2nd try Mac::Files: Carbon - unmaintained since 2006 except some 64bit fixes
+		$IMPLEMENTED_BY = 'File::HomeDir::Darwin::Carbon';
+	} else {
+		# 3rd: fallback: pure perl
 		$IMPLEMENTED_BY = 'File::HomeDir::Darwin';
 	}
 } elsif ( $^O eq 'MacOS' ) {
@@ -135,6 +130,62 @@ sub my_data {
 }
 
 
+sub my_dist_data {
+	my $params = ref $_[-1] eq 'HASH' ? pop : {};
+	my $dist   = pop or Carp::croak("The my_dist_data method requires an argument");
+	my $data   = my_data();
+
+        # If datadir is not defined, there's nothing we can do: bail out
+        # and return nothing...	
+	return undef unless defined $data;
+
+        # On traditional unixes, hide the top-level directory
+	my $var = $data eq home()
+		? File::Spec->catdir( $data, '.perl', 'dist', $dist )
+		: File::Spec->catdir( $data, 'Perl',  'dist', $dist );
+
+	# directory exists: return it
+	return $var if -d $var;
+
+	# directory doesn't exist: check if we need to create it...
+	return undef unless $params->{create};
+
+	# user requested directory creation
+	require File::Path;
+	File::Path::mkpath( $var );
+	return $var;
+}
+
+sub my_dist_config {
+	my $params = ref $_[-1] eq 'HASH' ? pop : {};
+	my $dist   = pop or Carp::croak("The my_dist_config method requires an argument");
+	
+	# not all platforms support a specific my_config() method
+	my $config = $IMPLEMENTED_BY->can('my_config')
+		? $IMPLEMENTED_BY->my_config
+		: $IMPLEMENTED_BY->my_documents;
+
+    # If neither configdir nor my_documents is defined, there's
+    # nothing we can do: bail out and return nothing...	
+	return undef unless defined $config;
+
+    # On traditional unixes, hide the top-level dir
+	my $etc = $config eq home()
+		? File::Spec->catdir( $config, '.perl', $dist )
+		: File::Spec->catdir( $config, 'Perl',  $dist );
+
+	# directory exists: return it
+	return $etc if -d $etc;
+
+	# directory doesn't exist: check if we need to create it...
+	return undef unless $params->{create};
+
+	# user requested directory creation
+	require File::Path;
+	File::Path::mkpath( $etc );
+	return $etc;
+}
+
 
 
 
@@ -187,7 +238,6 @@ sub users_data {
 
 
 
-
 #####################################################################
 # Legacy Methods
 
@@ -278,20 +328,22 @@ __END__
 
 =head1 NAME
 
-File::HomeDir - Find your home and other directories, on any platform
+File::HomeDir - Find your home and other directories on any platform
 
 =head1 SYNOPSIS
 
   use File::HomeDir;
   
   # Modern Interface (Current User)
-  $home    = File::HomeDir->my_home;
-  $desktop = File::HomeDir->my_desktop;
-  $docs    = File::HomeDir->my_documents;
-  $music   = File::HomeDir->my_music;
-  $pics    = File::HomeDir->my_pictures;
-  $videos  = File::HomeDir->my_videos;
-  $data    = File::HomeDir->my_data;
+  $home     = File::HomeDir->my_home;
+  $desktop  = File::HomeDir->my_desktop;
+  $docs     = File::HomeDir->my_documents;
+  $music    = File::HomeDir->my_music;
+  $pics     = File::HomeDir->my_pictures;
+  $videos   = File::HomeDir->my_videos;
+  $data     = File::HomeDir->my_data;
+  $dist     = File::HomeDir->my_dist_data('File-HomeDir');
+  $dist     = File::HomeDir->my_dist_config('File-HomeDir');
   
   # Modern Interface (Other Users)
   $home    = File::HomeDir->users_home('foo');
@@ -306,17 +358,17 @@ File::HomeDir - Find your home and other directories, on any platform
   print "My dir is ", home(), " and root's is ", home('root'), "\n";
   print "My dir is $~{''} and root's is $~{root}\n";
   # These both print the same thing, something like:
-  #  "My dir is /home/user/mojo and root's is /"
+  # "My dir is /home/user/mojo and root's is /"
 
 =head1 DESCRIPTION
 
-B<File::HomeDir> is a module for dealing with issues relating to the
-location of directories that are "owned" by a user, primarily your user,
-and to solve these issues consistently across a wide variety of
-platforms.
+B<File::HomeDir> is a module for locating the directories that are "owned"
+by a user (typicaly your user) and to solve the various issues that arise
+trying to find them consistently across a wide variety of platforms.
 
-Thus, a single API is presented that can find your resources on any
-platform.
+The end result is a single API that can find your resources on any platform,
+making it relatively trivial to create Perl software that works elegantly
+and correctly no matter where you run it.
 
 This module provides two main interfaces.
 
@@ -330,10 +382,10 @@ that exported a C<home()> function by default and tied the C<%~> variable.
 It is generally not recommended that you use this interface, but due to
 back-compatibility reasons they will remain supported until at least 2010.
 
-After this date, the home() function will remain, but we will consider
-deprecating the (namespace-polluting) C<%~> tied hash, to be removed by
-2015 (maintaining the general Perl convention of a 10 year support period
-for legacy APIs potentially or actually in common use).
+The C<%~> interface has been deprecated and is no longer documented. Any
+usage will issue warnings from 2013 and be removed in 2015 (in line with
+the general Perl convention of a 10 year support period for legacy APIs
+potentially or actually in common use).
 
 =head2 Platform Neutrality
 
@@ -463,8 +515,9 @@ user.
 
 Generally an application would create a subdirectory such as C<.foo>,
 beneath this directory, and store its data there. By creating your
-directory this way, you get an accurate result on the maximum number
-of platforms.
+directory this way, you get an accurate result on the maximum number of
+platforms. But see the documentation about C<my_dist_config()> or
+C<my_dist_data()> below.
 
 For example, on Unix you get C<~/.foo> and on Win32 you get
 C<~/Local Settings/Application Data/.foo>
@@ -472,6 +525,77 @@ C<~/Local Settings/Application Data/.foo>
 Returns the directory path as a string, C<undef> if the current user
 does not have a data directory, or dies on error.
 
+
+=head2 my_dist_config
+
+  File::HomeDir->my_dist_config( $dist [, \%params] );
+  
+  # For example...
+  
+  File::HomeDir->my_dist_config( 'File-HomeDir' );
+  File::HomeDir->my_dist_config( 'File-HomeDir', { create => 1 } );
+
+The C<my_dist_config> method takes a distribution name as argument and
+returns an application-specific directory where they should store their
+internal configuration.
+
+The base directory will be either C<my_config> if the platform supports
+it, or C<my_documents> otherwise. The subdirectory itself will be 
+C<BASE/Perl/Dist-Name>. If the base directory is the user's homedir,
+C<my_dist_config> will be in C<~/.perl/Dist-Name> (and thus be hidden on
+all Unixes).
+
+The optional last argument is a hash reference to tweak the method
+behaviour. The following hash keys are recognized:
+
+=over 4
+
+=item * create
+
+Passing a true value to this key will force the creation of the
+directory if it doesn't exist (remember that C<File::HomeDir>'s policy
+is to return C<undef> if the directory doesn't exist).
+
+Defaults to false, meaning no automatic creation of directory.
+
+=back
+
+
+=head2 my_dist_data
+
+  File::HomeDir->my_dist_data( $dist [, \%params] );
+  
+  # For example...
+  
+  File::HomeDir->my_dist_data( 'File-HomeDir' );
+  File::HomeDir->my_dist_data( 'File-HomeDir', { create => 1 } );
+
+The C<my_dist_data> method takes a distribution name as argument and
+returns an application-specific directory where they should store their
+internal data.
+
+This directory will be of course a subdirectory of C<my_data>. Platforms
+supporting data-specific directories will use
+C<DATA_DIR/perl/dist/Dist-Name> following the common
+"DATA/vendor/application" pattern. If the C<my_data> directory is the
+user's homedir, C<my_dist_data> will be in C<~/.perl/dist/Dist-Name>
+(and thus be hidden on all Unixes).
+
+The optional last argument is a hash reference to tweak the method
+behaviour. The following hash keys are recognized:
+
+=over 4
+
+=item * create
+
+Passing a true value to this key will force the creation of the
+directory if it doesn't exist (remember that C<File::HomeDir>'s policy
+is to return C<undef> if the directory doesn't exist).
+
+Defaults to false, meaning no automatic creation of directory.
+
+=back
+
 =head2 users_home
 
   $home = File::HomeDir->users_home('foo');
@@ -519,42 +643,6 @@ Returns the directory path to a named user's home/profile directory.
 If provided no param, returns the directory path to the current user's
 home/profile directory.
 
-=head1 TIED INTERFACE
-
-=head2 %~
-
-  $home = $~{""};
-  $home = $~{undef};
-  $home = $~{$user};
-  $home = $~{username};
-  print "... $~{''} ...";
-  print "... $~{$user} ...";
-  print "... $~{username} ...";
-
-This calls C<home($user)> or C<home('username')> -- except that if you
-ask for C<$~{some_user}> and there is no such user, it will die.
-
-Note that this is especially useful in double-quotish strings, like:
-
-     print "Jojo's .newsrc is ", -s "$~{jojo}/.newsrc", "b long!\n";
-      # (helpfully dies if there is no user 'jojo')
-
-If you want to avoid the fatal errors, first test the value of
-C<home('jojo')>, which will return undef (instead of dying) in case of
-there being no such user.
-
-Note, however, that if the hash key is "" or undef (whether thru being
-a literal "", or a scalar whose value is empty-string or undef), then
-this returns zero-argument C<home()>, i.e., your home directory:
-
-Further, please note that because the C<%~> hash compulsorily modifies
-a hash outside of it's namespace, and presents an overly simplistic
-approach to home directories, it is likely to ultimately be removed.
-
-The interface is currently expected to be formally deprecated from 2010
-(but no earlier) and removed from 2015 (but no earlier). If very heavy
-use is found in the wild, these plans may be pushed back.
-
 =head1 TO DO
 
 =over 4
@@ -628,6 +716,8 @@ Some parts copyright 2006 Chris Nandor.
 
 Some parts copyright 2006 Stephen Steneker.
 
+Some parts copyright 2009-2010 Jérôme Quelin.
+
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
