@@ -1,6 +1,6 @@
 package File::HomeDir::Unix;
 
-# Unix-specific functionality
+# See POD at the end of the file for documentation
 
 use 5.00503;
 use strict;
@@ -9,7 +9,7 @@ use File::HomeDir::Driver ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.91';
+	$VERSION = '0.93';
 	@ISA     = 'File::HomeDir::Driver';
 }
 
@@ -136,7 +136,7 @@ sub users_videos {
 
 =head1 NAME
 
-File::HomeDir::Unix - find your home and other directories, on Unix
+File::HomeDir::Unix - Find your home and other directories on legacy Unix
 
 =head1 SYNOPSIS
 
@@ -144,7 +144,6 @@ File::HomeDir::Unix - find your home and other directories, on Unix
   
   # Find directories for the current user
   $home    = File::HomeDir->my_home;        # /home/mylogin
-
   $desktop = File::HomeDir->my_desktop;     # All of these will... 
   $docs    = File::HomeDir->my_documents;   # ...default to home...
   $music   = File::HomeDir->my_music;       # ...directory
@@ -158,4 +157,30 @@ This module provides implementations for determining common user
 directories.  In normal usage this module will always be
 used via L<File::HomeDir>.
 
+=head1 SUPPORT
+
+See the support section the main L<File::HomeDir> module.
+
+=head1 AUTHORS
+
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+
+Sean M. Burke E<lt>sburke@cpan.orgE<gt>
+
+=head1 SEE ALSO
+
+L<File::HomeDir>, L<File::HomeDir::Win32> (legacy)
+
+=head1 COPYRIGHT
+
+Copyright 2005 - 2010 Adam Kennedy.
+
+Some parts copyright 2000 Sean M. Burke.
+
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
+
+The full text of the license can be found in the
+LICENSE file included with this module.
+
 =cut
